==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/EmbeddedRefDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var EmbeddedRefDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(EmbeddedRefDescription, _super);
    function EmbeddedRefDescription() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.f = null;
        _this.g = null;
        return _this;
    }
    EmbeddedRefDescription.prototype.get_type = function () {
        return "EmbeddedRef";
    };
    Object.defineProperty(EmbeddedRefDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(EmbeddedRefDescription.prototype, "refType", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("RefType");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(EmbeddedRefDescription.prototype, "value", {
        get: function () {
            return this.g;
        },
        set: function (a) {
            this.g = a;
            this.e("Value");
        },
        enumerable: true,
        configurable: true
    });
    EmbeddedRefDescription.$t = markType(EmbeddedRefDescription, 'EmbeddedRefDescription', Description.$);
    return EmbeddedRefDescription;
}(Description));
export { EmbeddedRefDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/EmbeddedRefDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var EmbeddedRefDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(EmbeddedRefDescription, _super);
    function EmbeddedRefDescription() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.h = null;
        _this.i = null;
        return _this;
    }
    EmbeddedRefDescription.prototype.get_type = function () {
        return "EmbeddedRef";
    };
    Object.defineProperty(EmbeddedRefDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(EmbeddedRefDescription.prototype, "refType", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.g("RefType");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(EmbeddedRefDescription.prototype, "value", {
        get: function () {
            return this.i;
        },
        set: function (a) {
            this.i = a;
            this.g("Value");
        },
        enumerable: false,
        configurable: true
    });
    EmbeddedRefDescription.$t = markType(EmbeddedRefDescription, 'EmbeddedRefDescription', Description.$);
    return EmbeddedRefDescription;
}(Description));
export { EmbeddedRefDescription };
